Crate macnuf

Crate macnuf 

This crate works by building a match at compile time which is then used to lookup in.

Structs

EUI48

Enums

EUI48ParseError

Functions

lookup
Lookup a manufacturer by a mac address.