Crate macnuf
macnuf
0.1.47+20260119
All Items
Crate Items
Structs
Enums
Functions
Crate
macnuf
This crate works by building a match at compile time which is then used to lookup in.
Structs

EUI48
Enums

EUI48
Parse
Error
Functions

lookup
Lookup a manufacturer by a mac address.